@@ -21,7 +21,7 @@ CRAWLED = set()
 session = requests.Session()
 
 
-def get_standings(contest_id, usernames=None, user_format=None):
+def get_standings(contest_id, usernames=None):
     # print('get_standings user_format = ', user_format)
     """
         usernames is list of usernames
@@ -94,12 +94,8 @@ def get_standings(contest_id, usernames=None, user_format=None):
         else:
             used_row['lastSubmissionTimeSeconds'] = 0
 
-        if user_format and re.match(user_format, used_row['handles']):
-            if usernames != None:
-                if used_row['handles'].lower() in usernames:
-                    standings['rows'].append(used_row)
-            else:
-                standings['rows'].append(used_row)
+        if used_row['handles'].lower() in usernames:
+            standings['rows'].append(used_row)
         else:
             standings['rows'].append(used_row)
     # print(json.dumps(standings, indent=2))
